@@ -1,13 +1,13 @@
 ;;; magit-annex.el --- Control git-annex from Magit  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2013-2021 Kyle Meyer <kyle@kyleam.com>
+;; Copyright (C) 2014-2024 all Magit-annex contributors
 
 ;; Author: Kyle Meyer <kyle@kyleam.com>
 ;;         Rémi Vanicat <vanicat@debian.org>
 ;; URL: https://github.com/magit/magit-annex
 ;; Keywords: vc tools
-;; Version: 1.8.1
-;; Package-Requires: ((cl-lib "0.3") (magit "3.0.0"))
+;; Version: 1.9.0
+;; Package-Requires: ((emacs "26.1") (magit "4.0.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -187,7 +187,7 @@ program used to open the unused file."
 
 ;;;###autoload (autoload 'magit-annex-dispatch "magit-annex" nil t)
 (transient-define-prefix magit-annex-dispatch ()
-  "Invoke a git-annex command."
+  "Invoke a git-annex command or offer to initialize non-annex repo."
   :man-page "git-annex"
   ["Actions"
    [("a" "Add" magit-annex-add)
@@ -201,7 +201,14 @@ program used to open the unused file."
     ("y" "Sync" magit-annex-sync)
     ("!" "Running" magit-annex-run-command)]
    [("u" "Unused" magit-annex-unused)
-    ("l" "List files" magit-annex-list)]])
+    ("l" "List files" magit-annex-list)]]
+  (interactive)
+  (cond
+   ((magit-annex-inside-annexdir-p)
+    (transient-setup 'magit-annex-dispatch))
+   ((y-or-n-p (format "No git-annex repository in %s.  Initialize one? "
+                      default-directory))
+    (call-interactively 'magit-annex-init))))
 
 (transient-define-prefix magit-annex-file-action ()
   "Invoke a git-annex file command."
@@ -216,8 +223,6 @@ program used to open the unused file."
    (magit-annex:--jobs)]
   ["Arguments for copy and move"
    (magit-annex:--to)]
-  ["Arguments for get, drop, copy, and move"
-   ("=f" "From remote" "--from=" magit-read-remote)]
   ["Actions"
    [("g" "Get" magit-annex-get-files)
     ("d" "Drop" magit-annex-drop-files)
@@ -270,9 +275,9 @@ program used to open the unused file."
 ;;;###autoload
 (eval-after-load 'magit
   '(progn
-     (define-key magit-mode-map "@" 'magit-annex-dispatch-or-init)
+     (define-key magit-mode-map "@" 'magit-annex-dispatch)
      (transient-append-suffix 'magit-dispatch '(0 -1 -1)
-       '("@" "Annex" magit-annex-dispatch-or-init))))
+       '("@" "Annex" magit-annex-dispatch))))
 
 
 ;;; Process calls
@@ -309,17 +314,6 @@ rather than \"git \" is used as the initial input."
 
 ;;; Initialization
 
-;;;###autoload
-(defun magit-annex-dispatch-or-init ()
-  "Call `magit-annex-dispatch' or offer to initialize non-annex repo."
-  (interactive)
-  (cond
-   ((magit-annex-inside-annexdir-p)
-    (magit-annex-dispatch))
-   ((y-or-n-p (format "No git-annex repository in %s.  Initialize one? "
-                      default-directory))
-    (call-interactively 'magit-annex-init))))
-
 ;;;###autoload
 (defun magit-annex-init (&optional description)
   "Initialize git-annex repository.
@@ -328,7 +322,7 @@ rather than \"git \" is used as the initial input."
   (magit-annex-run "init" description))
 
 (defun magit-annex-inside-annexdir-p ()
-  (file-exists-p (concat (magit-git-dir) "annex")))
+  (file-exists-p (expand-file-name "annex" (magit-gitdir))))
 
 
 ;;; Annexing
@@ -348,18 +342,18 @@ With a prefix argument, prompt for FILE.
                                          (magit-untracked-files))))))
   (if file
       (magit-annex-run "add" file)
-    (--when-let (magit-current-section)
+    (when-let ((section (magit-current-section)))
       (pcase (list (magit-diff-type) (magit-diff-scope))
         (`(untracked file)
          (magit-annex-run "add" (directory-file-name
-                                 (oref it value))))
+                                 (oref section value))))
         (`(untracked files)
          (magit-annex-run "add" (mapcar #'directory-file-name
                                         (magit-region-values))))
         (`(untracked list)
          (magit-annex-run "add" (magit-untracked-files)))
         (`(unstaged file)
-         (magit-annex-run "add" (oref it value)))
+         (magit-annex-run "add" (oref section value)))
         (`(unstaged files)
          (magit-annex-run "add" (magit-region-values)))
         (`(unstaged list)
@@ -514,49 +508,49 @@ arguments don't include --from."
 
 (defun magit-annex-get-files (files &optional args)
   "Get annex files.
-\('git annex get [ARGS] -- FILES)"
+\('git annex get [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments 'absent))
   (magit-annex-run-async "get" args "--" files)
   (magit-annex--dired-relist-async files))
 
 (defun magit-annex-drop-files (files &optional args)
   "Drop annex files.
-\('git annex drop [ARGS] -- FILES)"
+\('git annex drop [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments 'present t))
   (magit-annex-run-async "drop" args "--" files)
   (magit-annex--dired-relist-async files))
 
 (defun magit-annex-copy-files (files &optional args)
   "Copy annex files.
-\('git annex copy [ARGS] -- FILES)"
+\('git annex copy [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments 'present t))
   (magit-annex-run-async "copy" args "--" files)
   (magit-annex--dired-relist-async files))
 
 (defun magit-annex-move-files (files &optional args)
   "Move annex files.
-\('git annex move [ARGS] -- FILES)"
+\('git annex move [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments 'present t))
   (magit-annex-run-async "move" args "--" files)
   (magit-annex--dired-relist-async files))
 
 (defun magit-annex-unlock-files (files &optional args)
   "Unlock annex files.
-\('git annex unlock [ARGS] -- FILES)"
+\('git annex unlock [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments 'present))
   (magit-annex-run "unlock" args "--" files)
   (magit-annex--dired-relist files))
 
 (defun magit-annex-lock-files (files &optional args)
   "Lock annex files.
-\('git annex lock [ARGS] -- FILES)"
+\('git annex lock [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments 'unlocked))
   (magit-annex-run "lock" args "--" files)
   (magit-annex--dired-relist files))
 
 (defun magit-annex-undo-files (files &optional args)
   "Undo annex files.
-\('git annex undo [ARGS] -- FILES)"
+\('git annex undo [ARGS] -- FILES')"
   (interactive (magit-annex--file-arguments))
   (magit-annex-run "undo" args "--" files)
   (magit-annex--dired-relist files))
@@ -605,17 +599,7 @@ enabled if `magit-annex-unused-stat-argument' is non-nil.
        (when (and magit-annex-unused-stat-argument
                   (not (member "--stat" args)))
          (push "--stat" args))
-       (funcall
-        (cond
-         ;; `magit-git-log' was renamed to `magit-log-setup-buffer' in
-         ;; v2.90.1-480-g249ce0eec.  This is a temporary compatibility
-         ;; kludge for Guix, whose current version of Magit is from a
-         ;; bit before that (v2.90.1-460-gc761d28d4).
-         ((fboundp 'magit-log-setup-buffer)
-          #'magit-log-setup-buffer)
-         ((fboundp 'magit-git-log)
-          #'magit-git-log)
-         (t (error "bug: should never get here")))
+       (magit-log-setup-buffer
         (list (or (magit-get-current-branch) "HEAD"))
         (cons (concat "-S" (cdr (oref it value)))
               (cl-remove-if (lambda (x) (string-prefix-p "-S" x))
@@ -679,8 +663,6 @@ Type \\[magit-annex-unused-open] to open the file.
 ;;;###autoload
 (defun magit-annex-unused-in-refs (&optional args)
   "Show annex files not used in any branches or tags.
-These files are not pointed by the tips of the repositories
-branches or tags.
 \('git annex unused [ARGS]')"
   (interactive (list (magit-annex-unused-arguments)))
   (magit-annex-unused-setup-buffer args))
